@ECHO OFF
REM ------------------------------------------------------------------
REM File:	HOSTQUERY.BAT
REM Author:	M Shaw
REM Purpose:	Enumerate and query local network interfaces
REM 
REM Versions:
REM 1.00 06/Mar/2013 Handles up to 6 adapters
REM 1.01 07/Mar/2013 Copy to clipboard
REM 1.02 08/Mar/2013 Copy to clipboard with append
REM 1.03 11/Feb/2021 Script checks and improvements
REM ------------------------------------------------------------------
REM Dependencies:
REM ASK.EXE (v2.06+), SHOWIP.EXE (v1.14+), COPYCLIP.EXE (V1.01+)
REM ------------------------------------------------------------------

:start
CLS
ECHO Searching for network adapters ...
REM We check at start of loop in case a new adapter has been activated
SET ADAPTER_COUNT=
FOR /F "tokens=* usebackq" %%i in (`"%~dp0showip.exe"  /count`) DO SET ADAPTER_COUNT=%%i
IF /I %ADAPTER_COUNT% GTR 6 goto too_many_adapters
CLS 

ECHO.
"%~dp0ask.exe" " -- Query Network Adapter Settings -- " /message /f:white /b:lightblue /crlf
ECHO.
ECHO No. Adapter Description / Active IP Address
ECHO ----------------------------------------------------------------------------

REM Up to 6 adapters are presently handled (we can add more if nesc.)
IF %ADAPTER_COUNT%==0 goto no_adapters
FOR /F "tokens=* usebackq" %%i in (`"%~dp0showip.exe"  /cardname /1`) DO SET ADAPTER_1=%%i
FOR /F "tokens=* usebackq" %%i in (`"%~dp0showip.exe"  /ip /1`) DO SET ADDRESS_1=%%i
ECHO 1:  %ADAPTER_1%
ECHO         IP address: %ADDRESS_1%
IF %ADAPTER_COUNT%==1 goto done
FOR /F "tokens=* usebackq" %%i in (`"%~dp0showip.exe"  /cardname /2`) DO SET ADAPTER_2=%%i
FOR /F "tokens=* usebackq" %%i in (`"%~dp0showip.exe"  /ip /2`) DO SET ADDRESS_2=%%i
ECHO 2:  %ADAPTER_2%
ECHO         IP addr1ess: %ADDRESS_2%
IF %ADAPTER_COUNT%==2 goto done
FOR /F "tokens=* usebackq" %%i in (`"%~dp0showip.exe"  /cardname /3`) DO SET ADAPTER_3=%%i
FOR /F "tokens=* usebackq" %%i in (`"%~dp0showip.exe"  /ip /3`) DO SET ADDRESS_3=%%i
ECHO 3:  %ADAPTER_3%
ECHO         IP address: %ADDRESS_3%
IF %ADAPTER_COUNT%==3 goto done
FOR /F "tokens=* usebackq" %%i in (`"%~dp0showip.exe"  /cardname /4`) DO SET ADAPTER_4=%%i
FOR /F "tokens=* usebackq" %%i in (`"%~dp0showip.exe"  /ip /4`) DO SET ADDRESS_4=%%i
ECHO 4:  %ADAPTER_4%
ECHO         IP address: %ADDRESS_4%
IF %ADAPTER_COUNT%==4 goto done
FOR /F "tokens=* usebackq" %%i in (`"%~dp0showip.exe"  /cardname /5`) DO SET ADAPTER_5=%%i
FOR /F "tokens=* usebackq" %%i in (`"%~dp0showip.exe"  /ip /5`) DO SET ADDRESS_5=%%i
ECHO 5:  %ADAPTER_5%
ECHO         IP address: %ADDRESS_5%
IF %ADAPTER_COUNT%==5 goto done
FOR /F "tokens=* usebackq" %%i in (`"%~dp0showip.exe"  /cardname /6`) DO SET ADAPTER_6=%%i
FOR /F "tokens=* usebackq" %%i in (`"%~dp0showip.exe"  /ip /6`) DO SET ADDRESS_6=%%i
ECHO 6:  %ADAPTER_6%
ECHO         IP address: %ADDRESS_6%


:done
ECHO ----------------------------------------------------------------------------
ECHO.

REM Prompt the user...
REM ECHO Which adapter ? 1-%ADAPTER_COUNT%
REM TODO - make "%~dp0ask.exe" take a range value 1-N - /a:1-NQ
REM FIXME - finish this range value...
"%~dp0ask.exe" " Which adapter to query (Q quits)" /A:1-%ADAPTER_COUNT%Q /crlf  /f:yellow

REM Get the selected adapter information
REM ECHO Debug ERRORLEVEL is %ERRORLEVEL%
SET SELECTION=%ERRORLEVEL%

REM Handle cancel option first...
IF /I %SELECTION% GTR %ADAPTER_COUNT% goto cancelled
FOR /F "tokens=* usebackq" %%i in (`"%~dp0showip.exe"  /host /%SELECTION%`) DO SET HOSTNAME=%%i
FOR /F "tokens=* usebackq" %%i in (`"%~dp0showip.exe"  /mac /%SELECTION%`) DO SET MAC_ADDRESS=%%i

CLS
REM Display the selected adapter information
ECHO.
ECHO -- Host Details for Adapter %SELECTION% -----------------------------------------------
ECHO.
ECHO  Please note record the following RLM details for interface:
ECHO.
ECHO  Your PC host name is:           %HOSTNAME%
ECHO  Your host ID (MAC Address) is:  %MAC_ADDRESS%
ECHO.
ECHO ----------------------------------------------------------------------------
ECHO.
ECHO  Click the top left corner control box of this window and select Edit-Mark
ECHO  Select the text using the mouse and press ENTER to copy to the clipboard
ECHO.
"%~dp0ask.exe" " Copy this information to the clipboard" /A:YN /crlf /f:yellow
IF %ERRORLEVEL%==2 goto skip_copy

REM Copy text to the clipboard (will empty the clipboard) ...
ECHO RLM Details for Adapter %SELECTION% | "%~dp0copyclip.exe"
REM Run COPYCLIP.EXE in append mode
ECHO Your PC host name is:           %HOSTNAME% | "%~dp0copyclip.exe" /a
REM Run COPYCLIP.EXE in append mode
ECHO Your host ID (MAC Address) is:  %MAC_ADDRESS% | "%~dp0copyclip.exe" /a
IF %ERRORLEVEL%==0 ECHO  Copied successfully.

rem Debugging info
rem ECHO DEBUG: Full interface details (for information and diagnostic use only)
rem "%~dp0showip.exe"  /all /%SELECTION%
rem ECHO ----------------------------------------------------------------------------
ECHO.

:skip_copy
PAUSE
GOTO start

:cancelled
ECHO The action was cancelled by the user - exiting
goto end

:no_adapaters
ECHO No network adapters appear to have been found (count is zero)
goto end

:too_many_adapters
ECHO I can only handle up to 6 network adapters at present
ECHO Contact whoever supplied this script for an updated version
goto end

:end
ECHO.
REM Prevent immediate exit if launched from Explorer
PAUSE